OC.L10N.register(
    "spreed",
    {
    "a conversation" : "samtal",
    "(Duration %s)" : "(tímalengd %s)",
    "You attended a call with {user1}" : "Þú varst í símtali við {user1}",
    "_%n guest_::_%n guests_" : ["%n gestur","%n gestir"],
    "You attended a call with {user1} and {user2}" : "Þú varst í símtali við {user1} og {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Þú varst í símtali við {user1}, {user2} og {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Þú varst í símtali við {user1}, {user2}, {user3} og {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Þú varst í símtali við {user1}, {user2}, {user3}, {user4} og {user5}",
    "_%n other_::_%n others_" : ["%n annar","%n aðrir"],
    "{actor} invited you to {call}" : "{actor} bauð þér að taka þátt í {call}",
    "Talk" : "Spjalla",
    "Guest" : "Gestur",
    "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Velkomin í Nextcloud Talk-spjallforritið!\nÍ þessum spjallþræði verður þú upplýst/ur um nýja eigileika sem tiltækir eru í Nextcloud Talk.",
    "New in Talk 6" : "Nýtt í Talk 6",
    "New in Talk 7" : "Nýtt í Talk 7",
    "There are currently no commands available." : "Það eru engarskipanir tiltækar í augnablikinu.",
    "The command does not exist" : "Skipunin er ekki til",
    "Talk updates ✅" : "Uppfærslur á Talk-spjallforriti ✅",
    "{actor} created the conversation" : "{actor} bjó til samtalið",
    "You created the conversation" : "Þú bjóst til samtalið",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} endurnefndi samtalið \"%1$s\" sem \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Þú endurnefndir samtalið \"%1$s\" sem \"%2$s\"",
    "{actor} started a call" : "{actor} hóf samtal",
    "You started a call" : "Þú hófst samtal",
    "{actor} joined the call" : "{actor} kom inn í samtalið",
    "You joined the call" : "Þú komst inn í samtalið",
    "{actor} left the call" : "{actor} hætti í samtalinu",
    "You left the call" : "Þú hættir í samtalinu",
    "{actor} unlocked the conversation" : "{actor} aflæsti samtalinu",
    "You unlocked the conversation" : "Þú aflæstir samtalinu",
    "{actor} locked the conversation" : "{actor} læsti samtalinu",
    "You locked the conversation" : "Þú læstir samtalinu",
    "{actor} allowed guests" : "{actor} leyfði gesti",
    "You allowed guests" : "Þú leyfðir gesti",
    "{actor} disallowed guests" : "{actor} bannaði gesti",
    "You disallowed guests" : "Þú bannaðir gesti",
    "{actor} set a password" : "{actor} setti lykilorð",
    "You set a password" : "Þú stilltir lykilorð",
    "{actor} removed the password" : "{actor} fjarlægði lykilorð",
    "You removed the password" : "Þú} fjarlægðir lykilorð",
    "{actor} added {user}" : "{actor} bætti {user} við",
    "You joined the conversation" : "Þú komst inn í samtalið",
    "{actor} joined the conversation" : "{actor} kom inn í samtalið",
    "You added {user}" : "Þú bættir {user} við",
    "{actor} added you" : "{actor} bætti þér við",
    "You left the conversation" : "Þú hættir í samtalinu",
    "{actor} left the conversation" : "{actor} hætti í samtalinu",
    "{actor} removed {user}" : "{actor} fjarlægði {user}",
    "You removed {user}" : "Þú fjarlægðir {user}",
    "{actor} removed you" : "{actor} fjarlægði þig",
    "{actor} promoted {user} to moderator" : "{actor} gerði {user} að umsjónarmanni",
    "You promoted {user} to moderator" : "Þú gerðir {user} að umsjónarmanni",
    "{actor} promoted you to moderator" : "{actor} gerði þig að umsjónarmanni",
    "{actor} demoted {user} from moderator" : "{actor} lét {user} hætta sem umsjónarmann",
    "You demoted {user} from moderator" : "Þú lést {user} hætta sem umsjónarmann",
    "{actor} demoted you from moderator" : "{actor} lét þig hætta sem umsjónarmann",
    "{actor} shared a file which is no longer available" : "{actor} deildi skrá sem ekki er lengur tiltæk",
    "You shared a file which is no longer available" : "Þú deildir skrá sem ekki er lengur tiltæk",
    "%s (guest)" : "%s (gestur)",
    "Call with {user1} and {user2} (Duration {duration})" : "Samtal við {user1} og {user2} (tímalengd {duration})",
    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Samtal við {user1}, {user2} og {user3} (tímalengd {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Samtal við {user1}, {user2}, {user3} og {user4} (tímalengd {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Samtal við {user1}, {user2}, {user3}, {user4} og {user5} (tímalengd {duration})",
    "Talk to %s" : "Tala við %s",
    "File is not shared, or shared but not with the user" : "Skránni er ekki deilt, eða henni er deilt en ekki með notandanum",
    "%s invited you to a conversation." : "%s bauð þér að taka þátt í samtali.",
    "You were invited to a conversation." : "Þér var boðið að taka þátt í samtali.",
    "Conversation invitation" : "Boð í samtal",
    "Click the button below to join." : "Smelltu á hnappinn hér fyrir neðan til að taka þátt.",
    "Join »%s«" : "Taka þátt í »%s«",
    "Password request: %s" : "Beiðni um lykilorð: %s",
    "Private conversation" : "Einkasamtal",
    "Deleted user (%s)" : "Eyddi notanda (%s)",
    "{user} sent you a private message" : "{user} sendi þér einkaskilaboð",
    "{user} sent a message in conversation {call}" : "{user} sendi skilaboð í samtali {call}",
    "A deleted user sent a message in conversation {call}" : "Eyddur notandi sendi skilaboð í samtali {call}",
    "{guest} (guest) sent a message in conversation {call}" : " {guest} (gestur) sendi skilaboð í samtali {call}",
    "A guest sent a message in conversation {call}" : "Gestur sendi skilaboð í samtali {call}",
    "{guest} (guest) replied to your message in conversation {call}" : " {guest} (gestur) svaraði skilaboðunum þinum í samtalinu {call}",
    "{user} mentioned you in a private conversation" : "{user} minntist á þig í einkasamtali",
    "{user} mentioned you in conversation {call}" : "{user} minntist á þig í samtali {call}",
    "A deleted user mentioned you in conversation {call}" : "Eyddur notandi minntist á þig í samtali {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (gestur) minntist á þig í samtali {call}",
    "A guest mentioned you in conversation {call}" : "Gestur minntist á þig í samtali {call}",
    "View chat" : "Skoða spjall",
    "{user} invited you to a private conversation" : "{user} bauð þér að taka þátt í einkasímtali",
    "Join call" : "Taka þátt í símtali",
    "{user} invited you to a group conversation: {call}" : "{user} bauð þér að taka þátt í hópsímtali: {call}",
    "Answer call" : "Svara símtali",
    "{user} wants to talk with you" : "{user} vill tala við þig",
    "Call back" : "Hringja til baka",
    "A group call has started in {call}" : "Hópsímtal er byrjað í {call}",
    "Invalid date, date format must be YYYY-MM-DD" : "Ógild dagsetning, dagsetningasniðið verður að vera ÁÁÁÁ-MM-DD",
    "Conversation not found" : "Samtal fannst ekki",
    "Path is already shared with this room" : "Slóðinni er þegar deilt með þessu spjallsvæði",
    "Chat, video & audio-conferencing using WebRTC" : "Spjall, mynd- og hljóðfundir með WebRTC",
    "Leave call" : "Hætta símtali",
    "Share this file" : "Deila þessari skrá",
    "Request password" : "Biðja um lykilorð",
    "Error requesting the password." : "Villa kom upp við að biðja um lykilorð.",
    "This conversation has ended" : "Þessu samtali er lokið",
    "Limit to groups" : "Takmarka við hópa",
    "Guests can still join public conversations." : "Gestir geta komið inn í opinber samtöl.",
    "Users that can not use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Notendur sem ekki geta lengur notað Talk-spjallforritið verða samt áfram taldir sem þátttakendur í fyrri samtölum sínum og verður einnig haldið upp á spjallskilaboð þeirra.",
    "Everyone" : "Allir",
    "Users and moderators" : "Notendur og umsjónarmenn",
    "Moderators only" : "Aðeins umsjónarmenn",
    "Save changes" : "Vista breytingar",
    "Saving …" : "Vista …",
    "Saved!" : "Vistað!",
    "None" : "Enginn",
    "User" : "Notandi",
    "Disabled" : "Óvirkt",
    "Moderators" : "Umsjónarmenn",
    "Users" : "Notendur",
    "Commands" : "Skipanir",
    "Beta" : "BETA-prófunarútgáfa",
    "Name" : "Nafn",
    "Command" : "Skipun",
    "Script" : "Skrifta",
    "Response to" : "Svar til",
    "Enabled for" : "Virkjað fyrir",
    "General settings" : "Almennar stillingar",
    "All messages" : "Öll skilaboð",
    "Off" : "Slökkt",
    "Signaling server URL" : "Slóð á merkjasendingaþjón",
    "Validate SSL certificate" : "Sannreyna SSL-skilríki",
    "Delete this server" : "Eyða þessum þjóni",
    "Signaling servers" : "Merkjasendingaþjónar",
    "Saved" : "Vistað",
    "Add a new server" : "Bæta við nýjum þjóni",
    "An external signaling server should optionally be used for larger installations. Leave empty to use the internal signaling server." : "Mögulegt er að nota utanaðkomandi merkjasendingaþjón fyrir mjög stórar uppsetningar. Skildu þetta eftir autt til að nota innbyggða merkjasendingaþjóninn.",
    "Please note that calls with more than 4 participants without external signaling server, participants can experience connectivity issues and cause high load on participating devices." : "Athugaðu að samtöl með fleiri en 4 þátttakendum og án merkjasendingaþjóns geta orðið fyrir truflunum í tengingum ásamt því að valda miklu álagi á tengdum tækjum.",
    "Shared secret" : "Sameiginlegur leynilykill",
    "STUN server URL" : "URL-slóð STUN-þjóns",
    "STUN servers" : "STUN-þjónar",
    "A STUN server is used to determine the public IP address of participants behind a router." : "STUN-miðlari er notaður til að ákvarða opinbert vistfang þátttakenda á bak við beini.",
    "TURN server URL" : "URL-slóð TURN-þjóns",
    "TURN server secret" : "Leynilykill á TURN-miðlara",
    "TURN server protocols" : "Samskiptareglur TURN-þjóns",
    "UDP and TCP" : "UDP og TCP",
    "UDP only" : "Aðeins UDP",
    "TCP only" : "Aðeins TCP",
    "Test this server" : "Prófa þennan þjón",
    "TURN servers" : "TURN-miðlarar",
    "Copy link" : "Afrita tengil",
    "Waiting for others to join the call …" : "Bíð eftir að fleiri komi inn í símtalið …",
    "You can invite others in the participant tab of the sidebar" : "Þú getur boðið öðrum að taka þátt af þátttakendaflipa hliðarspjaldsins",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Þú getur boðið öðrum að taka þátt af þátttakendaflipa hliðarspjaldsins eða deilt þessum tengli til að bjóða öðrum!",
    "Share this link to invite others!" : "Deildu þessum tengli til að bjóða öðrum!",
    "Share whole screen" : "Deila öllum skjánum",
    "Share a single window" : "Deila stökum glugga",
    "Show your screen" : "Birta skjáinn þinn",
    "Stop screensharing" : "Hætta skjádeilingu",
    "No audio" : "Ekkert hljóð",
    "Mute audio (m)" : "Þagga hljóð (m)",
    "Unmute audio (m)" : "Afþagga hljóð (m)",
    "Mute audio" : "Þagga hljóð",
    "Disable video (v)" : "Gera myndskeið óvirk (v)",
    "Enable video (v)" : "Virkja myndskeið (v)",
    "Enable video (v) - Your connection will be briefly interrupted when enabling the video for the first time" : "Virkja myndskeið (v) - Tengingin þín verður trufluð í stutta stund á meðan myndmerkið er virkjað í fyrsta skipti",
    "Disable video" : "Gera myndskeið óvirk",
    "Enable video" : "Virkja myndskeið",
    "Screensharing options" : "Valkostir skjádeilingar",
    "Enable screensharing" : "Virkja skjádeilingu",
    "Screensharing requires the page to be loaded through HTTPS." : "Deiling á skjá krefst þess að síðunni sé hlaðið inn með HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "Skjádeiling virkar aðeins með Firefox útgáfu 52 eða nýrri.",
    "Screensharing extension is required to share your screen." : "Það þarf skjádeili-viðaukann til að hægt sé að deila skjánum.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Veldu einhvern annan vafra eins og Firefox eða Chrome til að deila skjánum þínum.",
    "An error occurred while starting screensharing." : "Villa kom upp við að hefja skjádeilingu.",
    "You" : "Þú",
    "Show screen" : "Birta skjá",
    "Favorite" : "Eftirlæti",
    "Leave conversation" : "Hætta í samtali",
    "Delete conversation" : "Eyða samtali",
    "Remove from favorites" : "Fjarlægja úr eftirlætum",
    "Add to favorites" : "Bæta í eftirlæti",
    "You need to promote a new moderator before you can leave the conversation." : "Þú þarft að uppfæra einhvern í stöðu umsjónarmanna áður en þú getur hætt í samtalinu.",
    "Conversations" : "Samtöl",
    "Loading" : "Hleð inn",
    "Groups" : "Hópar",
    "Circles" : "Hringir",
    "Invalid path selected" : "Ógild slóð valin",
    "Error" : "Villa",
    "Password protect" : "Verja með lykilorði",
    "Back" : "Til baka",
    "Close" : "Loka",
    "Conversation name" : "Heiti samtals",
    "Reply" : "Svara",
    "Today" : "Í dag",
    "Yesterday" : "Í gær",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Send message" : "Senda skilaboð",
    "File to share" : "Skrá til að deila",
    "moderator" : "umsjónarmaður",
    "guest" : "gestanotandi",
    "Demote from moderator" : "Láta hætta sem umsjónarmann",
    "Promote to moderator" : "Gera að umsjónarmanni",
    "Remove participant" : "Fjarlægja þátttakanda",
    "Searching …" : "Leita …",
    "No results" : "Engar niðurstöður",
    "Add users or groups" : "Bæta við notendum eða hópum",
    "Participants" : "Þátttakendur",
    "Chat" : "Spjall",
    "Projects" : "Verkefni",
    "Settings" : "Stillingar",
    "Edit" : "Breyta",
    "Start call" : "Hefja samtal",
    "Dismiss" : "Hafna",
    "Go to file" : "Fara í skrá",
    "Rename conversation" : "Endurnefna samtal",
    "Share link" : "Deila tengli",
    "Password protection" : "Verndun með lykilorði",
    "Enter a password" : "Settu inn lykilorð",
    "Start time (optional)" : "Upphafstími (valfrjálst)",
    "Exit fullscreen (f)" : "Hætta í skjáfylli (f)",
    "Fullscreen (f)" : "Fylla skjáinn (f)",
    "Grid view" : "Reitasýn",
    "Select a conversation to add to the project" : "Veldu samtal sem á að bæta við verkefnið",
    "Select conversation" : "Veldu samtal",
    "Join a conversation or start a new one" : "Taktu þátt í samtali eða byrjaðu nýtt samtal",
    "Say hi to your friends and colleagues!" : "Segðu hæ við vini þína og samstarfsmenn!",
    "Link to a conversation" : "Tengill á samtal",
    "Access to microphone & camera is only possible with HTTPS" : "Aðgangur að hljóðnema og myndavél er einungis mögulegur í gegnum HTTPS",
    "Please move your setup to HTTPS" : "Endilega færðu uppsetninguna þína yfir í HTTPS",
    "Access to microphone & camera was denied" : "Aðgangur að hljóðnema og myndavél var ekki heimilaður",
    "WebRTC is not supported in your browser" : "WebRTC er ekki stutt í vafranum þínum",
    "Please use a different browser like Firefox or Chrome" : "Veldu einhvern annan vafra eins og Firefox eða Chrome",
    "Error while accessing microphone & camera" : "Villa kom upp þegar reynt var að opna hljóðnema og myndavél",
    "This conversation is password-protected" : "Þetta samtal er er varið með lykilorði",
    "The password is wrong. Try again." : "Lykilorðið er rangt. Reyndu aftur.",
    "Password" : "Lykilorð",
    "Specify commands the users can use in chats" : "Tilgreindu hvaða skipanir notendur geta notað í spjalli",
    "TURN server" : "TURN-þjónn",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN-miðlari er notaður sem milliþjónn umferðar þátttakenda á bak við eldvegg.",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Mögulegt er að nota utanaðkomandi merkjasendingaþjón fyrir mjög stórar uppsetningar. Skildu þetta eftir autt til að nota innbyggða merkjasendingaþjóninn.",
    "%s Talk on your mobile devices" : "%s Talaðu á snjalltækjunum þínum",
    "Android app" : "Android-forrit",
    "iOS app" : "iOS-forrit",
    "Enter name for a new conversation" : "Settu inn nafn fyrir nýtt samtal",
    "{name} (public)" : "{name} (opinbert)",
    "New conversation …" : "Nýtt samtal…",
    "Calls with more than 4 participants without an external signaling server can experience connectivity issues and cause high load on participating devices." : "Samtöl með fleiri en 4 þátttakendum og án merkjasendingaþjóns geta orðið fyrir truflunum í tengingum ásamt því að valda miklu álagi á tengdum tækjum.",
    "Copy" : "Afrita",
    "Copied!" : "Afritað!",
    "Not supported!" : "Ekki stutt!",
    "Press ⌘-C to copy." : "Ýttu á ⌘-C til að afrita.",
    "Press Ctrl-C to copy." : "Ýttu á Ctrl-C til að afrita.",
    "Error while getting the room ID" : "Villa kom upp við að sækja auðkennisnúmer spjallsvæðis",
    "Room name can not be empty" : "Nafn á spjallsvæði má ekki vera autt",
    "Please enter the password for this call" : "Settu inn lykilorðið fyrir þetta símtal",
    "Password required" : "Lykilorðs er krafist",
    "Cancel" : "Hætta við",
    "Submit" : "Senda inn",
    "Calls are disabled in this conversation." : "Símtöl eru óvirk í þessu samtali",
    "Guests" : "Gestir",
    "Change password" : "Breyta lykilorði",
    "Set password" : "Stilltu lykilorð",
    "Rename" : "Endurnefna",
    "Link copied!" : "Tengill afritaður!",
    "Conversation with {name}" : "Samtal við {name}",
    "Error occurred while setting password" : "Villa kom upp við að stilla lykilorð",
    "No messages yet, start the conversation!" : "Engin skilaboð ennþá, byrjaðu umræðuna!",
    "New message …" : "Ný skilaboð …",
    "Send" : "Senda",
    "You can not send messages, because the conversation is locked." : "Þú getur ekki sent skilaboð því samtalið er læst.",
    "The conversation is locked." : "Samtalið er læst.",
    "Share" : "Deila",
    "[Unknown user name]" : "[nafn óþekkts notanda]",
    "The message you are trying to send is too long" : "Skilaboðin sem þú ert að reyna að senda eru of löng",
    "Error occurred while sending message" : "Villa kom upp við að senda inn skilaboð",
    "Error while sharing" : "Villa við deilingu",
    "No other people in this call" : "Engir aðrir í þessu símtali",
    "Waiting for {participantName} to join the call …" : "Bíð eftir að {participantName} komi inn í símtalið …",
    "WebRTC is not supported in your browser :-/" : "WebRTC er ekki stutt í vafranum þínum :-/",
    "Waiting for camera and microphone permissions" : "Bíð eftir heimildum fyrir hljóðnema og myndavél",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "Til að nota þetta forrit, þarftu að gefa vafranum þínum heimild til að nota hljóðnema og myndavél.",
    "Set your name in the chat window so other participants can identify you better." : "Settu nafnið þitt í spjallgluggann svo að aðrir þáttakendur eigi auðveldara með að þekkja þig.",
    "Share screen" : "Deila skjá",
    "No Camera" : "Engin myndavél",
    "Screensharing is not supported by your browser." : "Deiling á skjá er ekki studd í vafranum þínum",
    "Error while promoting user to moderator" : "Villa við að gera notanda að umsjónarmanni",
    "Error while demoting moderator" : "Villa við að láta hætta sem umsjónarmann",
    "Error while removing user from room" : "Villa við að fjarlægja notanda úr spjallsvæði",
    "Add participant …" : "Bæta við þátttakanda…",
    "Favorited" : "Sett í eftirlæti",
    "Your screen" : "Skjárinn þinn",
    "{participantName}'s screen" : "Skjár {participantName}",
    "Guest's screen" : "Skjár gests",
    "Limit app usage to groups." : "Takmarka notkun forrits við tiltekna hópa.",
    "Commands are a new beta feature in Nextcloud Talk. They allow you to run scripts on your Nextcloud server. You can define them with our command line interface. An example of a calculator script can be found in our <a {attributes}>documentation ↗</a>." : "Skipanir er nýr eiginleiki í Nextcloud Talk. Þær gera þér kleift að keyra skriftur á Nextcloud-þjóninum þínum. Þú getur skilgreint þær með skipanalínuviðmóti okkar. Þæmi um reiknivélarskriftu má finna í <a {attributes}>hjálparskjölunum ↗</a>.",
    "A TURN server is used to proxy the traffic from participants behind a firewall." : "TURN-miðlari er notaður sem milliþjónn umferðar þátttakenda á bak við eldvegg.",
    "Join conversations at any time, any where, on any device." : "Taktu þátt í samtölum hvenær sem er, hvar sem er, á hvaða tæki sem er.",
    "Contacts" : "Tengiliðir",
    "Search conversations or contacts" : "Leita í samtölum eða tengiliðum"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
